/*
 * PROJECT:     Test
 * LICENSE:     EUPL - https://joinup.ec.europa.eu/software/page/eupl
 * PURPOSE:     Demo for RC Supplement Library
 * PROGRAMMERS: Ștefan Fulea (stefan.fulea@mail.md)
 */

#include <WinDef.h>
#include <WinBase.h>
#include <WinCon.h>
#include <stdlib.h>

#include "test.h"
#include "rcsuplib.h"

int wmain (int argc, WCHAR *argvW[])
{
    HINSTANCE hModuleHandle = GetModuleHandleW(NULL);
    DWORD nOut;
    WCHAR wsUnformattedBuffer[MAXSTRING] =  L"Provide either one or two "
                                            L"numerical parameters to test "
                                            L"the gramatical-number dependence."
                                            L"\nExample: "
                                            L"\"test 3\" or \"test 0 20\"";
    WCHAR wsFormattedBuffer[MAXSTRING] = L"\n";
    INT nDecidingValue;
    INT nLowBound, nHighBound;
    PVOID pRuleSet, pCachedStringSet;

    switch(argc)
    {
    case 1:
        WriteConsoleW(GetStdHandle(STD_OUTPUT_HANDLE),
                      wsUnformattedBuffer,
                      wcslen(wsUnformattedBuffer),
                      &nOut, NULL);
        break;
    case 2:
        /* demo for a simple, low-rate-change resource updating case */
        nDecidingValue = _wtoi(argvW[1]);

        LoadNDRString(hModuleHandle,
                      GNDR_STRSET_ID,
                      wsUnformattedBuffer,
                      MAXSTRING,
                      nDecidingValue);

        FreePosArgsStrFormat(wsFormattedBuffer,
                             MAXSTRING,
                             wsUnformattedBuffer,
                             nDecidingValue);

        WriteConsoleW(GetStdHandle(STD_OUTPUT_HANDLE),
                      wsFormattedBuffer,
                      wcslen(wsFormattedBuffer),
                      &nOut, NULL);
        break;
    case 3:
        /* demo for a cached, high-rate-change resource updating case */
        nLowBound = _wtoi(argvW[1]);
        nHighBound = _wtoi(argvW[2]);

        RetreiveNDRRuleSet(hModuleHandle,
                           GNDR_RULESET_ID,
                           &pRuleSet);

        LoadNDRStringSetCache(hModuleHandle,
                              GNDR_STRSET_ID,
                              &pCachedStringSet);

        for (nDecidingValue = nLowBound;
             nDecidingValue <= nHighBound;
             nDecidingValue++)
        {
            FreePosArgsStrFormat(wsFormattedBuffer + 1,
                                 MAXSTRING,
                                 GetNDRString(pRuleSet,
                                              pCachedStringSet,
                                              nDecidingValue),
                                 nDecidingValue);

            WriteConsoleW(GetStdHandle(STD_OUTPUT_HANDLE),
                          wsFormattedBuffer,
                          wcslen(wsFormattedBuffer),
                          &nOut, NULL);
        }

        FreeNDRStringSetCache(pCachedStringSet);
    };

    return 0;
}

/* EOF */
